@@ -12,15 +12,16 @@ class ExtendedEnum(Enum):
 
 
 class TopicEnum(ExtendedEnum):
-    brainsteam = "brainsteam"
+    brainstorm_ideas = "brainstormIdeas"
     blog_post = "blogPost"
     outline = "outline"
     social_media_post = "socialMediaPost"
-    creative_story = "creativeStory"
-    poem = "poem"
-    essay = "essay"
-    meeting_agenda = "meetingAgenda"
     press_release = "pressRelease"
+    creative_story = "creativeStory"
+    essay = "essay"
+    poem = "poem"
+    meeting_agenda = "meetingAgenda"
+    pros_cons_list = "prosConsList"
     job_description = "jobDescription"
     sales_email = "salesEmail"
     recruiting_email = "recruitingEmail"
@@ -32,8 +33,8 @@ class TranslateLanguageEnum(ExtendedEnum):
     chinese = "chinese"
     japanese = "japanese"
     spanish = "spanish"
-    russiab = "russia"
-    french = "frence"
+    russiab = "russiab"
+    french = "french"
     german = "german"
     italian = "italian"
     portuguese = "portuguese"
@@ -46,6 +47,7 @@ class TranslateLanguageEnum(ExtendedEnum):
 class PromptTypeEnum(ExtendedEnum):
     help_me_write = "helpMeWrite"
     continue_writing = "continueWriting"
+    change_tone = "changeTone"
     summarize = "summarize"
     improve_writing = "improveWriting"
     fix_spelling_grammar = "fixSpellingGrammar"
@@ -56,3 +58,11 @@ class PromptTypeEnum(ExtendedEnum):
     find_action_items = "findActionItems"
     simplify_language = "simplifyLanguage"
     help_me_edit = "helpMeEdit"
+
+
+class ToneEnum(ExtendedEnum):
+    professional = "professional"
+    casual = "casual"
+    straight_forward = "straightForward"
+    confident = "confident"
+    friendly = "friendly"
